@@ -17,9 +17,8 @@
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
 """the cubicweb-ctl tool, based on logilab.common.clcommands to
 provide a pluggable commands system.
-
-
 """
+
 __docformat__ = "restructuredtext en"
 
 # *ctl module should limit the number of import to be imported as quickly as
@@ -477,23 +476,23 @@ running.'}),
 
     def start_instance(self, appid):
         """start the instance's server"""
-        debug = self['debug']
-        force = self['force']
-        loglevel = self['loglevel']
-        config = cwcfg.config_for(appid)
-        if loglevel is not None:
-            loglevel = 'LOG_%s' % loglevel.upper()
-            config.global_set_option('log-threshold', loglevel)
-            config.init_log(loglevel, debug=debug, force=True)
+        config = cwcfg.config_for(appid, debugmode=self['debug'])
+        init_cmdline_log_threshold(config, self['loglevel'])
         if self['profile']:
             config.global_set_option('profile', self.config.profile)
         helper = self.config_helper(config, cmdname='start')
         pidf = config['pid-file']
-        if exists(pidf) and not force:
+        if exists(pidf) and not self['force']:
             msg = "%s seems to be running. Remove %s by hand if necessary or use \
 the --force option."
             raise ExecutionError(msg % (appid, pidf))
-        helper.start_server(config, debug)
+        helper.start_server(config)
+
+
+def init_cmdline_log_threshold(config, loglevel):
+    if loglevel is not None:
+        config.global_set_option('log-threshold', loglevel.upper())
+        config.init_log(config['log-threshold'], force=True)
 
 
 class StopInstanceCommand(InstanceCommand):
@@ -731,7 +730,9 @@ given, appropriate sources for migration will be automatically selected \
         if cubicwebversion > applcubicwebversion:
             toupgrade.append(('cubicweb', applcubicwebversion, cubicwebversion))
         if not self.config.fs_only and not toupgrade:
-            print '-> no software migration needed for instance %s.' % appid
+            print '-> no data migration needed for instance %s.' % appid
+            self.i18nupgrade(config)
+            mih.shutdown()
             return
         for cube, fromversion, toversion in toupgrade:
             print '-> migration needed from %s to %s for %s' % (fromversion, toversion, cube)
@@ -742,21 +743,10 @@ given, appropriate sources for migration will be automatically selected \
         mih.migrate(vcconf, reversed(toupgrade), self.config)
         # rewrite main configuration file
         mih.rewrite_configuration()
-        # handle i18n upgrade:
-        # * install new languages
-        # * recompile catalogs
-        # XXX search available language in the first cube given
-        from cubicweb import i18n
-        templdir = cwcfg.cube_dir(config.cubes()[0])
-        langs = [lang for lang, _ in i18n.available_catalogs(join(templdir, 'i18n'))]
-        errors = config.i18ncompile(langs)
-        if errors:
-            print '\n'.join(errors)
-            if not ASK.confirm('Error while compiling message catalogs, '
-                               'continue anyway ?'):
-                print '-> migration not completed.'
-                return
         mih.shutdown()
+        # handle i18n upgrade
+        if not self.i18nupgrade(config):
+            return
         print
         print '-> instance migrated.'
         if not (CWDEV or self.config.nostartstop):
@@ -768,6 +758,22 @@ given, appropriate sources for migration will be automatically selected \
                 print '%s exited with status %s' % (forkcmd, status)
         print
 
+    def i18nupgrade(self, config):
+        # handle i18n upgrade:
+        # * install new languages
+        # * recompile catalogs
+        # XXX search available language in the first cube given
+        from cubicweb import i18n
+        templdir = cwcfg.cube_dir(config.cubes()[0])
+        langs = [lang for lang, _ in i18n.available_catalogs(join(templdir, 'i18n'))]
+        errors = config.i18ncompile(langs)
+        if errors:
+            print '\n'.join(errors)
+            if not ASK.confirm('Error while compiling message catalogs, '
+                               'continue anyway?'):
+                print '-> migration not completed.'
+                return False
+        return True
 
 class ShellCommand(Command):
     """Run an interactive migration shell on an instance. This is a python shell
@@ -781,11 +787,15 @@ class ShellCommand(Command):
     repository internals (session, etc...) so most migration commands won't be
     available.
 
+    Arguments after bare "--" string will not be processed by the shell command
+    You can use it to pass extra arguments to your script and expect for
+    them in '__args__' afterwards.
+
     <instance>
       the identifier of the instance to connect.
     """
     name = 'shell'
-    arguments = '<instance> [batch command file]'
+    arguments = '<instance> [batch command file(s)] [-- <script arguments>]'
     options = (
         ('system-only',
          {'short': 'S', 'action' : 'store_true',
@@ -861,8 +871,11 @@ sources for migration will be automatically selected.",
             mih = config.migration_handler()
         try:
             if args:
-                for arg in args:
-                    mih.cmd_process_script(arg)
+                # use cmdline parser to access left/right attributes only
+                # remember that usage requires instance appid as first argument
+                scripts, args = self.cmdline_parser.largs[1:], self.cmdline_parser.rargs
+                for script in scripts:
+                    mih.cmd_process_script(script, scriptargs=args)
             else:
                 mih.interactive_shell()
         finally:
