@@ -20,10 +20,11 @@
 Take a look at http://www.python.org/peps/pep-0249.html
 
 (most parts of this document are reported here in docstrings)
-
 """
+
 __docformat__ = "restructuredtext en"
 
+from threading import currentThread
 from logging import getLogger
 from time import time, clock
 from itertools import count
@@ -254,9 +255,6 @@ class DBAPIRequest(RequestSessionBase):
             self.session = None
             self.cnx = self.user = _NeedAuthAccessMock()
 
-    def base_url(self):
-        return self.vreg.config['base-url']
-
     def from_controller(self):
         return 'view'
 
@@ -403,6 +401,9 @@ class Cursor(object):
         """no effect"""
         pass
 
+    def _txid(self):
+        return self.connection._txid(self)
+
     def execute(self, rql, args=None, eid_key=None, build_descr=True):
         """execute a rql query, return resulting rows and their description in
         a :class:`~cubicweb.rset.ResultSet` object
@@ -438,7 +439,8 @@ class Cursor(object):
             warn('[3.8] eid_key is deprecated, you can safely remove this argument',
                  DeprecationWarning, stacklevel=2)
         # XXX use named argument for build_descr in case repo is < 3.8
-        rset = self._repo.execute(self._sessid, rql, args, build_descr=build_descr)
+        rset = self._repo.execute(self._sessid, rql, args,
+                                  build_descr=build_descr, **self._txid())
         rset.req = self.req
         return rset
 
@@ -477,6 +479,10 @@ class Connection(object):
         if cnxprops and cnxprops.log_queries:
             self.executed_queries = []
             self.cursor_class = LogCursor
+        if self._cnxtype == 'pyro':
+            # check client/server compat
+            if self._repo.get_versions()['cubicweb'] < (3, 8, 6):
+                self._txid = lambda cursor=None: {}
 
     def __repr__(self):
         if self.anonymous_connection:
@@ -493,6 +499,10 @@ class Connection(object):
             self.rollback()
             return False #propagate the exception
 
+    def _txid(self, cursor=None): # XXX could now handle various isolation level!
+        # return a dict as bw compat trick
+        return {'txid': currentThread().getName()}
+
     def request(self):
         return DBAPIRequest(self.vreg, DBAPISession(self))
 
@@ -535,8 +545,7 @@ class Connection(object):
             raise ProgrammingError('Closed connection')
         return self._repo.get_schema()
 
-    def load_appobjects(self, cubes=_MARKER, subpath=None, expand=True,
-                        force_reload=None):
+    def load_appobjects(self, cubes=_MARKER, subpath=None, expand=True):
         config = self.vreg.config
         if cubes is _MARKER:
             cubes = self._repo.get_cubes()
@@ -555,18 +564,12 @@ class Connection(object):
             esubpath = list(subpath)
             esubpath.remove('views')
             esubpath.append(join('web', 'views'))
-        cubes = reversed([config.cube_dir(p) for p in cubes])
-        vpath = config.build_vregistry_path(cubes, evobjpath=esubpath,
+        cubespath = [config.cube_dir(p) for p in cubes]
+        config.load_site_cubicweb(cubespath)
+        vpath = config.build_vregistry_path(reversed(cubespath),
+                                            evobjpath=esubpath,
                                             tvobjpath=subpath)
-        self.vreg.register_objects(vpath, force_reload)
-        if self._cnxtype == 'inmemory':
-            # should reinit hooks manager as well
-            hm, config = self._repo.hm, self._repo.config
-            hm.set_schema(hm.schema) # reset structure
-            hm.register_system_hooks(config)
-            # instance specific hooks
-            if self._repo.config.instance_hooks:
-                hm.register_hooks(config.load_hooks(self.vreg))
+        self.vreg.register_objects(vpath)
 
     def use_web_compatible_requests(self, baseurl, sitetitle=None):
         """monkey patch DBAPIRequest to fake a cw.web.request, so you should
@@ -576,6 +579,7 @@ class Connection(object):
         """
         from cubicweb.web.request import CubicWebRequestBase as cwrb
         DBAPIRequest.build_ajax_replace_url = cwrb.build_ajax_replace_url.im_func
+        DBAPIRequest.ajax_replace_url = cwrb.ajax_replace_url.im_func
         DBAPIRequest.list_form_param = cwrb.list_form_param.im_func
         DBAPIRequest.property_value = _fake_property_value
         DBAPIRequest.next_tabindex = count().next
@@ -635,7 +639,7 @@ class Connection(object):
     def describe(self, eid):
         if self._closed is not None:
             raise ProgrammingError('Closed connection')
-        return self._repo.describe(self.sessionid, eid)
+        return self._repo.describe(self.sessionid, eid, **self._txid())
 
     def close(self):
         """Close the connection now (rather than whenever __del__ is called).
@@ -648,7 +652,7 @@ class Connection(object):
         """
         if self._closed:
             raise ProgrammingError('Connection is already closed')
-        self._repo.close(self.sessionid)
+        self._repo.close(self.sessionid, **self._txid())
         del self._repo # necessary for proper garbage collection
         self._closed = 1
 
@@ -662,7 +666,7 @@ class Connection(object):
         """
         if not self._closed is None:
             raise ProgrammingError('Connection is already closed')
-        return self._repo.commit(self.sessionid)
+        return self._repo.commit(self.sessionid, **self._txid())
 
     def rollback(self):
         """This method is optional since not all databases provide transaction
@@ -675,7 +679,7 @@ class Connection(object):
         """
         if not self._closed is None:
             raise ProgrammingError('Connection is already closed')
-        self._repo.rollback(self.sessionid)
+        self._repo.rollback(self.sessionid, **self._txid())
 
     def cursor(self, req=None):
         """Return a new Cursor Object using the connection.
@@ -715,6 +719,7 @@ class Connection(object):
           only searched in 'public' actions, unless a `public` argument is given
           and set to false.
         """
+        actionfilters.update(self._txid())
         txinfos = self._repo.undoable_transactions(self.sessionid, ueid,
                                                    **actionfilters)
         if req is None:
@@ -730,7 +735,8 @@ class Connection(object):
         allowed (eg not in managers group and the transaction doesn't belong to
         him).
         """
-        txinfo = self._repo.transaction_info(self.sessionid, txuuid)
+        txinfo = self._repo.transaction_info(self.sessionid, txuuid,
+                                             **self._txid())
         if req is None:
             req = self.request()
         txinfo.req = req
@@ -746,7 +752,8 @@ class Connection(object):
         session's user is not allowed (eg not in managers group and the
         transaction doesn't belong to him).
         """
-        return self._repo.transaction_actions(self.sessionid, txuuid, public)
+        return self._repo.transaction_actions(self.sessionid, txuuid, public,
+                                              **self._txid())
 
     def undo_transaction(self, txuuid):
         """Undo the given transaction. Return potential restoration errors.
@@ -755,4 +762,5 @@ class Connection(object):
         allowed (eg not in managers group and the transaction doesn't belong to
         him).
         """
-        return self._repo.undo_transaction(self.sessionid, txuuid)
+        return self._repo.undo_transaction(self.sessionid, txuuid,
+                                           **self._txid())
