@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""classes to define schemas for CubicWeb
+"""classes to define schemas for CubicWeb"""
 
-"""
 __docformat__ = "restructuredtext en"
 _ = unicode
 
