@@ -15,9 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""user authentication component
+"""user authentication component"""
 
-"""
 from __future__ import with_statement
 
 __docformat__ = "restructuredtext en"
