@@ -22,6 +22,7 @@ _ = unicode
 
 from logilab.mtconverter import BINARY_ENCODINGS, TransformError, xml_escape
 
+from cubicweb import tags
 from cubicweb.view import EntityView
 from cubicweb.selectors import (one_line_rset, is_instance, match_context_prop,
                                 adaptable, has_mimetype)
@@ -94,6 +95,7 @@ class DownloadView(EntityView):
     def last_modified(self):
         return self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0).modification_date
 
+
 class DownloadLinkView(EntityView):
     """view displaying a link to download the file"""
     __regid__ = 'downloadlink'
@@ -111,13 +113,16 @@ class IDownloadablePrimaryView(primary.PrimaryView):
     __select__ = adaptable('IDownloadable')
 
     def render_entity_attributes(self, entity):
-        super(IDownloadablePrimaryView, self).render_entity_attributes(entity)
         self.w(u'<div class="content">')
         adapter = entity.cw_adapt_to('IDownloadable')
         contenttype = adapter.download_content_type()
         if contenttype.startswith('image/'):
-            self.wview('image', entity.cw_rset, row=entity.cw_row)
+            self._cw.add_js('cubicweb.image.js')
+            self.wview('image', entity.cw_rset, row=entity.cw_row, col=entity.cw_col,
+                       link=True, klass='contentimage')
+            super(IDownloadablePrimaryView, self).render_entity_attributes(entity)
         else:
+            super(IDownloadablePrimaryView, self).render_entity_attributes(entity)
             self.wview('downloadlink', entity.cw_rset, title=self._cw._('download'), row=entity.cw_row)
             self.render_data(entity, contenttype, 'text/html')
         self.w(u'</div>')
@@ -136,6 +141,7 @@ class IDownloadablePrimaryView(primary.PrimaryView):
             return True
         return False
 
+
 class IDownloadableLineView(baseviews.OneLineView):
     __select__ = adaptable('IDownloadable')
 
@@ -156,25 +162,19 @@ class ImageView(EntityView):
 
     title = _('image')
 
-    def call(self):
+    def call(self, **kwargs):
         rset = self.cw_rset
         for i in xrange(len(rset)):
             self.w(u'<div class="efile">')
-            self.wview(self.__regid__, rset, row=i, col=0)
+            self.wview(self.__regid__, rset, row=i, col=0, **kwargs)
             self.w(u'</div>')
 
-    def cell_call(self, row, col, width=None, height=None, link=False):
+    def cell_call(self, row, col, link=False, **kwargs):
         entity = self.cw_rset.get_entity(row, col)
         adapter = entity.cw_adapt_to('IDownloadable')
-        #if entity.data_format.startswith('image/'):
-        imgtag = u'<img src="%s" alt="%s" ' % (
-            xml_escape(adapter.download_url()),
-            (self._cw._('download %s')  % xml_escape(adapter.download_file_name())))
-        if width:
-            imgtag += u'width="%i" ' % width
-        if height:
-            imgtag += u'height="%i" ' % height
-        imgtag += u'/>'
+        imgtag = tags.img(src=adapter.download_url(),
+                          alt=(self._cw._('download %s') % adapter.download_file_name()),
+                          **kwargs)
         if link:
             self.w(u'<a href="%s">%s</a>' % (entity.absolute_url(vid='download'),
                                              imgtag))
